CREATE DATABASE SUMINISTROS

USE SUMINISTROS



CREATE TABLE PROVEEDORES(
	IDPROVEEDOR SMALLINT IDENTITY(1,1) PRIMARY KEY,
	NOMPROVE VARCHAR (50) NOT NULL,
)


CREATE UNIQUE INDEX CK_INDICE ON PROVEEDORES(NOMPROVE)




CREATE TABLE PROYECTOS(
	IDPROYECTO SMALLINT NOT NULL,
	IDDEPARTAMENTO CHAR(4) NOT NULL,
	NOMPROYECTO VARCHAR (80) NOT NULL,
	PRESUPUESTO MONEY NOT NULL,
)


CREATE RULE LETRAYNUMEROS
AS (@CAMPO LIKE ('[A-Z][0-9][0-9][0-9]'))


EXEC SP_BINDRULE LETRAYNUMEROS,'PROYECTOS.IDDEPARTAMENTO'


CREATE RULE POSITIVO 
AS (@CAMPO > 0)


EXEC SP_BINDRULE POSITIVO, 'PROYECTOS.PRESUPUESTO'


ALTER TABLE PROYECTOS
ADD CONSTRAINT PK_PROYECTOS
PRIMARY KEY (IDPROYECTO,IDDEPARTAMENTO)


CREATE TABLE DEPARTAMENTOS(
	IDDEPARTAMENTO CHAR(4) PRIMARY KEY,
	NOMDPTO VARCHAR(50) NOT NULL,
	PRESUPUESTO MONEY NOT NULL,
)



CREATE UNIQUE  INDEX CK_INDICE2 ON DEPARTAMENTOS(NOMDPTO)

ALTER TABLE PROYECTOS
ADD CONSTRAINT FK_PROYECTOS_DEPARTAMENTOS
FOREIGN KEY (IDDEPARTAMENTO)
REFERENCES DEPARTAMENTOS(IDDEPARTAMENTO)

EXEC SP_BINDRULE POSITIVO,'DEPARTAMENTOS.PRESUPUESTO'





EXEC SP_BINDRULE LETRAYNUMEROS,'DEPARTAMENTOS.IDDEPARTAMENTO'


CREATE TABLE ARTICULOS(
	IDARTICULO CHAR(7) PRIMARY KEY,
	DESCRIPCION VARCHAR(70) NOT NULL,
	STOCK INT NOT NULL,
	PRECIO_MAXIMO_COMPRA MONEY NOT NULL,
	PRECIO_VENTA MONEY NOT NULL,
)


EXEC SP_BINDRULE POSITIVO,'ARTICULOS.[PRECIO_MAXIMO_COMPRA]'


ALTER TABLE ARTICULOS
ADD CONSTRAINT CK_MAYORIGUAL
CHECK (STOCK >= 0)


CREATE RULE LETRASNUMEROS
AS (@CAMPO LIKE ('[A-Z][A-Z][A-Z][0-9][0-9][0-9][0-9]'))


EXEC SP_BINDRULE LETRASNUMEROS,'ARTICULOS.IDARTICULO'


ALTER TABLE ARTICULOS
ADD CONSTRAINT CK_PRECIOS
CHECK([PRECIO_VENTA]>[PRECIO_MAXIMO_COMPRA])



CREATE TABLE SUMINISTRAN(
	IDPROYECTO SMALLINT NOT NULL,
	IDDEPARTAMENTO CHAR(4) NOT NULL,
	IDARTICULO CHAR(7) NOT NULL,
	IDPROVEEDOR SMALLINT NOT NULL,
	CANTIDAD SMALLINT NOT NULL,
	PRECIO MONEY  NOT NULL,
)


ALTER TABLE SUMINISTRAN
ADD CONSTRAINT PK_SUMINISTRAN
PRIMARY KEY(IDPROYECTO,IDDEPARTAMENTO,IDARTICULO,IDPROVEEDOR)


EXEC SP_BINDRULE POSITIVO,'SUMINISTRAN.CANTIDAD'
EXEC SP_BINDRULE POSITIVO,'SUMINISTRAN.PRECIO'


EXEC SP_BINDRULE LETRAYNUMEROS,'SUMINISTRAN.IDDEPARTAMENTO'
EXEC SP_BINDRULE LETRASNUMEROS,'SUMINISTRAN.IDARTICULO'


ALTER TABLE SUMINISTRAN
ADD CONSTRAINT FK_SUMINISTRAN_PROYECTOS
FOREIGN KEY (IDPROYECTO,IDDEPARTAMENTO)
REFERENCES PROYECTOS(IDPROYECTO,IDDEPARTAMENTO)


ALTER TABLE SUMINISTRAN
ADD CONSTRAINT FK_SUMINISTRAN_ARTICULOS
FOREIGN KEY (IDARTICULO)
REFERENCES ARTICULOS(IDARTICULO)


ALTER TABLE SUMINISTRAN
ADD CONSTRAINT FK_SUMINISTRAN_PROVEEDORES
FOREIGN KEY (IDPROVEEDOR)
REFERENCES PROVEEDORES(IDPROVEEDOR)


